@@ -76,6 +76,10 @@ func (r *Request) AuthorizeRequest(
 		r.Form.Set("code_challenge_method", "S256")
 	}
 
+	if cconfig.Claims != "" {
+		r.Form.Set("claims", cconfig.Claims)
+	}
+
 	if cconfig.RequestObject || cconfig.EncryptedRequestObject {
 		claims := RequestObjectClaims(r.Form, sconfig, cconfig)
 
@@ -164,12 +168,12 @@ func (r *Request) AuthenticateClient(
 		r.Form.Set("client_assertion", clientAssertion)
 	case TLSClientAuthMethod, SelfSignedTLSAuthMethod:
 		r.Form.Set("client_id", cconfig.ClientID)
-		endpoint = mtlsEndpoint
+	}
 
-		if tr, ok := hc.Transport.(*http.Transport); ok {
-			if len(tr.TLSClientConfig.Certificates) > 0 {
-				r.Cert, _ = x509.ParseCertificate(tr.TLSClientConfig.Certificates[0].Certificate[0])
-			}
+	if tr, ok := hc.Transport.(*http.Transport); ok {
+		if len(tr.TLSClientConfig.Certificates) > 0 {
+			r.Cert, _ = x509.ParseCertificate(tr.TLSClientConfig.Certificates[0].Certificate[0])
+			endpoint = mtlsEndpoint
 		}
 	}
 
